"use strict";
/**
 * @file This plugin is to access classification image data from different sources. Make sure that
 * the data is conform to expectation.
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const pipcook_core_1 = require("@pipcook/pipcook-core");
const glob_promise_1 = __importDefault(require("glob-promise"));
const path = __importStar(require("path"));
const imageDetectronDataAccess = (data, args) => __awaiter(void 0, void 0, void 0, function* () {
    if (Array.isArray(data)) {
        throw new Error('only one dataset can be specified');
    }
    const { trainDataPath, validationDataPath, testDataPath } = data;
    const trainFiles = yield glob_promise_1.default(path.join(trainDataPath, '*.xml'));
    let validationFiles = [];
    if (validationDataPath) {
        validationFiles = yield glob_promise_1.default(path.join(validationDataPath, '*.xml'));
        yield pipcook_core_1.convertPascol2CocoFileOutput(validationFiles, path.join(trainDataPath, '..', 'validation.json'));
    }
    let testFiles = [];
    if (testDataPath) {
        testFiles = yield glob_promise_1.default(path.join(testDataPath, '*.xml'));
        yield pipcook_core_1.convertPascol2CocoFileOutput(testFiles, path.join(trainDataPath, '..', 'test.json'));
    }
    yield pipcook_core_1.convertPascol2CocoFileOutput(trainFiles, path.join(trainDataPath, '..', 'train.json'));
    const trainJsonContent = require(path.join(trainDataPath, '..', 'train.json'));
    const categories = trainJsonContent.categories;
    const oneHotMap = {};
    categories.forEach((category) => {
        oneHotMap[category.name] = category.id;
    });
    const result = {
        trainData: path.join(trainDataPath, '..', 'train.json'),
        metaData: {
            feature: {
                name: 'xs',
                type: 'float32',
                shape: []
            },
            label: {
                name: 'ys',
                type: 'int32',
                shape: [],
                valueMap: oneHotMap
            },
        }
    };
    if (validationFiles.length > 0) {
        result.validationData = path.join(trainDataPath, '..', 'validation.json');
    }
    if (testFiles.length > 0) {
        result.testData = path.join(trainDataPath, '..', 'test.json');
    }
    return result;
});
exports.default = imageDetectronDataAccess;
//# sourceMappingURL=index.js.map